Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(120)

Unified Diff: src/compiler/node.h

Issue 1348073002: [turbofan] Get rid of type lower bounds. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Rebase Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/js-typed-lowering.cc ('k') | src/compiler/node.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/node.h
diff --git a/src/compiler/node.h b/src/compiler/node.h
index e6c9f23fdc4daf1385bad1e11febe321e0fbacc8..bd129653bc3397510a53169c0ce48ae9ef411004 100644
--- a/src/compiler/node.h
+++ b/src/compiler/node.h
@@ -284,9 +284,9 @@ class Node final {
void* operator new(size_t, void* location) { return location; }
- // Only NodeProperties should manipulate the bounds.
- Bounds bounds() const { return bounds_; }
- void set_bounds(Bounds b) { bounds_ = b; }
+ // Only NodeProperties should manipulate the type.
+ Type* type() const { return type_; }
+ void set_type(Type* type) { type_ = type; }
// Only NodeMarkers should manipulate the marks on nodes.
Mark mark() { return mark_; }
@@ -306,7 +306,7 @@ class Node final {
static const int kMaxInlineCapacity = InlineCapacityField::kMax - 1;
const Operator* op_;
- Bounds bounds_;
+ Type* type_;
Mark mark_;
uint32_t bit_field_;
Use* first_use_;
« no previous file with comments | « src/compiler/js-typed-lowering.cc ('k') | src/compiler/node.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698